rafted_value v0.7.0 RaftedValue.Persistence.SnapshotMetadata View Source
Link to this section Summary
Functions
Type-aware getter for last_committed_index
Type-aware setter for last_committed_index
Creates a new instance of RaftedValue.Persistence.SnapshotMetadata by using the given dict
A variant of new/1 which returns t or raise if validation fails
Type-aware getter for path
Type-aware setter for path
Type-aware getter for size
Type-aware setter for size
Type-aware getter for term
Type-aware setter for term
Updates an existing instance of RaftedValue.Persistence.SnapshotMetadata with the given dict.
The values in the dict are validated by each field’s valid?/1 function.
Returns {:ok, valid_struct} or {:error, reason}
A variant of update/2 which returns t or raise if validation fails.
In other words, update/2 followed by Croma.Result.get!/1
Checks if the given value belongs to t/0 or not
Link to this section Types
t() :: %RaftedValue.Persistence.SnapshotMetadata{last_committed_index: RaftedValue.LogIndex.t(), path: Croma.String.t(), size: Croma.PosInteger.t(), term: RaftedValue.TermNumber.t()}
Link to this section Functions
last_committed_index(t()) :: RaftedValue.LogIndex.t()
Type-aware getter for last_committed_index.
last_committed_index(t(), RaftedValue.LogIndex.t()) :: t()
Type-aware setter for last_committed_index.
Creates a new instance of RaftedValue.Persistence.SnapshotMetadata by using the given dict.
For missing fields, default/0 of each field type will be used.
Returns {:ok, valid_struct} or {:error, reason}.
The values in the dict are validated by each field’s valid?/1 function.
A variant of new/1 which returns t or raise if validation fails.
In other words, new/1 followed by Croma.Result.get!/1.
Type-aware getter for path.
Type-aware setter for path.
Type-aware getter for size.
Type-aware setter for size.
Type-aware getter for term.
Type-aware setter for term.
Updates an existing instance of RaftedValue.Persistence.SnapshotMetadata with the given dict.
The values in the dict are validated by each field’s valid?/1 function.
Returns {:ok, valid_struct} or {:error, reason}.
A variant of update/2 which returns t or raise if validation fails.
In other words, update/2 followed by Croma.Result.get!/1.
Checks if the given value belongs to t/0 or not.