rafted_value v0.7.2 RaftedValue.RPC.RequestVoteRequest View Source
Link to this section Summary
Functions
Type-aware getter for candidate_pid
Type-aware setter for candidate_pid
Type-aware getter for last_log
Type-aware setter for last_log
Creates a new instance of RaftedValue.RPC.RequestVoteRequest by using the given dict
A variant of new/1 which returns t or raise if validation fails
Type-aware getter for replacing_leader
Type-aware setter for replacing_leader
Type-aware getter for term
Type-aware setter for term
Updates an existing instance of RaftedValue.RPC.RequestVoteRequest with the given dict.
The values in the dict are validated by each field’s valid?/1 function.
Returns {:ok, valid_struct} or {:error, reason}
A variant of update/2 which returns t or raise if validation fails.
In other words, update/2 followed by Croma.Result.get!/1
Checks if the given value belongs to t/0 or not
Link to this section Types
t() :: %RaftedValue.RPC.RequestVoteRequest{candidate_pid: Croma.Atom.t(), last_log: RaftedValue.LogInfo.t(), replacing_leader: Croma.Boolean.t(), term: RaftedValue.TermNumber.t()}
Link to this section Functions
candidate_pid(t()) :: Croma.Atom.t()
Type-aware getter for candidate_pid.
Type-aware setter for candidate_pid.
last_log(t()) :: RaftedValue.LogInfo.t()
Type-aware getter for last_log.
Type-aware setter for last_log.
Creates a new instance of RaftedValue.RPC.RequestVoteRequest by using the given dict.
For missing fields, default/0 of each field type will be used.
Returns {:ok, valid_struct} or {:error, reason}.
The values in the dict are validated by each field’s valid?/1 function.
A variant of new/1 which returns t or raise if validation fails.
In other words, new/1 followed by Croma.Result.get!/1.
replacing_leader(t()) :: Croma.Boolean.t()
Type-aware getter for replacing_leader.
replacing_leader(t(), Croma.Boolean.t()) :: t()
Type-aware setter for replacing_leader.
term(t()) :: RaftedValue.TermNumber.t()
Type-aware getter for term.
Type-aware setter for term.
Updates an existing instance of RaftedValue.RPC.RequestVoteRequest with the given dict.
The values in the dict are validated by each field’s valid?/1 function.
Returns {:ok, valid_struct} or {:error, reason}.
A variant of update/2 which returns t or raise if validation fails.
In other words, update/2 followed by Croma.Result.get!/1.
Checks if the given value belongs to t/0 or not.