rafted_value v0.7.2 RaftedValue.RPC.RequestVoteResponse View Source
Link to this section Summary
Functions
Type-aware getter for from
Type-aware setter for from
Creates a new instance of RaftedValue.RPC.RequestVoteResponse by using the given dict
A variant of new/1 which returns t or raise if validation fails
Type-aware getter for term
Type-aware setter for term
Updates an existing instance of RaftedValue.RPC.RequestVoteResponse with the given dict.
The values in the dict are validated by each field’s valid?/1 function.
Returns {:ok, valid_struct} or {:error, reason}
A variant of update/2 which returns t or raise if validation fails.
In other words, update/2 followed by Croma.Result.get!/1
Checks if the given value belongs to t/0 or not
Type-aware getter for vote_granted
Type-aware setter for vote_granted
Link to this section Types
t() :: %RaftedValue.RPC.RequestVoteResponse{from: Croma.Pid.t(), term: RaftedValue.TermNumber.t(), vote_granted: Croma.Boolean.t()}
Link to this section Functions
Type-aware getter for from.
Type-aware setter for from.
Creates a new instance of RaftedValue.RPC.RequestVoteResponse by using the given dict.
For missing fields, default/0 of each field type will be used.
Returns {:ok, valid_struct} or {:error, reason}.
The values in the dict are validated by each field’s valid?/1 function.
A variant of new/1 which returns t or raise if validation fails.
In other words, new/1 followed by Croma.Result.get!/1.
term(t()) :: RaftedValue.TermNumber.t()
Type-aware getter for term.
Type-aware setter for term.
Updates an existing instance of RaftedValue.RPC.RequestVoteResponse with the given dict.
The values in the dict are validated by each field’s valid?/1 function.
Returns {:ok, valid_struct} or {:error, reason}.
A variant of update/2 which returns t or raise if validation fails.
In other words, update/2 followed by Croma.Result.get!/1.
Checks if the given value belongs to t/0 or not.
vote_granted(t()) :: Croma.Boolean.t()
Type-aware getter for vote_granted.
vote_granted(t(), Croma.Boolean.t()) :: t()
Type-aware setter for vote_granted.