rafted_value v0.7.2 RaftedValue.RPC.TimeoutNow View Source
Link to this section Summary
Functions
Type-aware getter for append_entries_req
Type-aware setter for append_entries_req
Creates a new instance of RaftedValue.RPC.TimeoutNow by using the given dict
A variant of new/1 which returns t or raise if validation fails
Updates an existing instance of RaftedValue.RPC.TimeoutNow with the given dict.
The values in the dict are validated by each field’s valid?/1 function.
Returns {:ok, valid_struct} or {:error, reason}
A variant of update/2 which returns t or raise if validation fails.
In other words, update/2 followed by Croma.Result.get!/1
Checks if the given value belongs to t/0 or not
Link to this section Types
t() :: %RaftedValue.RPC.TimeoutNow{append_entries_req: RaftedValue.RPC.AppendEntriesRequest.t()}
Link to this section Functions
append_entries_req(t()) :: RaftedValue.RPC.AppendEntriesRequest.t()
Type-aware getter for append_entries_req.
append_entries_req(t(), RaftedValue.RPC.AppendEntriesRequest.t()) :: t()
Type-aware setter for append_entries_req.
Creates a new instance of RaftedValue.RPC.TimeoutNow by using the given dict.
For missing fields, default/0 of each field type will be used.
Returns {:ok, valid_struct} or {:error, reason}.
The values in the dict are validated by each field’s valid?/1 function.
A variant of new/1 which returns t or raise if validation fails.
In other words, new/1 followed by Croma.Result.get!/1.
Updates an existing instance of RaftedValue.RPC.TimeoutNow with the given dict.
The values in the dict are validated by each field’s valid?/1 function.
Returns {:ok, valid_struct} or {:error, reason}.
A variant of update/2 which returns t or raise if validation fails.
In other words, update/2 followed by Croma.Result.get!/1.
Checks if the given value belongs to t/0 or not.